inline GEKVECTOR3 operator - (const GEKVECTOR3 &kVector)
{
	return GEKVECTOR3(-kVector.x,
					  -kVector.y,
					  -kVector.z);
}

inline GEKVECTOR3 operator - (GEKVECTOR3 &kVector)
{
	return GEKVECTOR3(-kVector.x,
					  -kVector.y,
					  -kVector.z);
}

inline GEKVECTOR3::GEKVECTOR3(void)
{
	x = y = z = 0.0f;
}

inline GEKVECTOR3::GEKVECTOR3(const GEKVECTOR2 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	z = 0.0f;
}

inline GEKVECTOR3::GEKVECTOR3(const GEKVECTOR3 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	z = kVector.z;
}

inline GEKVECTOR3::GEKVECTOR3(const GEKVECTOR4 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	z = kVector.z;
}

inline GEKVECTOR3::GEKVECTOR3(float fX, float fY, float fZ)
{
	x = fX;
	y = fY;
	z = fZ;
}

inline float &GEKVECTOR3::operator [] (int iAxis)
{
	return xyz[iAxis];
}

inline bool GEKVECTOR3::operator < (const GEKVECTOR3 &kVector) const
{
	if((x < kVector.x)&&
	   (y < kVector.y)&&
	   (z < kVector.z)) return true;
	return false;
}

inline bool GEKVECTOR3::operator > (const GEKVECTOR3 &kVector) const
{
	if((x > kVector.x)&&
	   (y > kVector.y)&&
	   (z > kVector.z)) return true;
	return false;
}

inline GEKVECTOR3::operator float * (void)
{
	return &x;
}

inline GEKVECTOR3::operator const float * (void) const
{
	return &x;
}

inline GEKVECTOR3::operator -= (const GEKVECTOR3 &kVector)
{
	x -= kVector.x;
	y -= kVector.y;
	z -= kVector.z;
}

inline GEKVECTOR3::operator += (const GEKVECTOR3 &kVector)
{
	x += kVector.x;
	y += kVector.y;
	z += kVector.z;
}

inline GEKVECTOR3::operator /= (float fScalar)
{
	x /= fScalar;
	y /= fScalar;
	z /= fScalar;
}

inline GEKVECTOR3::operator *= (float fScalar)
{
	x *= fScalar;
	y *= fScalar;
	z *= fScalar;
}

inline GEKVECTOR3 GEKVECTOR3::operator = (const GEKVECTOR2 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	z = 0.0f;
	return *this;
}

inline GEKVECTOR3 GEKVECTOR3::operator = (const GEKVECTOR3 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	z = kVector.z;
	return *this;
}

inline GEKVECTOR3 GEKVECTOR3::operator = (const GEKVECTOR4 &kVector)
{
	x = kVector.x;
	y = kVector.y;
	z = kVector.z;
	return *this;
}

inline GEKVECTOR3 GEKVECTOR3::operator - (const GEKVECTOR3 &kVector) const
{
	return GEKVECTOR3((x - kVector.x),
					  (y - kVector.y),
					  (z - kVector.z));
}

inline GEKVECTOR3 GEKVECTOR3::operator + (const GEKVECTOR3 &kVector) const
{
	return GEKVECTOR3((x + kVector.x),
					  (y + kVector.y),
					  (z + kVector.z));
}

inline GEKVECTOR3 GEKVECTOR3::operator - (const GEKVECTOR3 &kVector)
{
	return GEKVECTOR3((x - kVector.x),
					  (y - kVector.y),
					  (z - kVector.z));
}

inline GEKVECTOR3 GEKVECTOR3::operator + (const GEKVECTOR3 &kVector)
{
	return GEKVECTOR3((x + kVector.x),
					  (y + kVector.y),
					  (z + kVector.z));
}

inline GEKVECTOR3 GEKVECTOR3::operator / (float fScalar) const
{
	return GEKVECTOR3((x / fScalar),
				  	  (y / fScalar),
					  (z / fScalar));
}

inline GEKVECTOR3 GEKVECTOR3::operator * (float fScalar) const
{
	return GEKVECTOR3((x * fScalar),
					  (y * fScalar),
					  (z * fScalar));
}

inline GEKVECTOR3 GEKVECTOR3::operator / (float fScalar)
{
	return GEKVECTOR3((x / fScalar),
				  	  (y / fScalar),
					  (z / fScalar));
}

inline GEKVECTOR3 GEKVECTOR3::operator * (float fScalar)
{
	return GEKVECTOR3((x * fScalar),
					  (y * fScalar),
					  (z * fScalar));
}

inline float GEKVECTOR3::Dot(const GEKVECTOR3 &kVector) const
{
	return ((x * kVector.x) +
			(y * kVector.y) + 
			(z * kVector.z));
}

inline float GEKVECTOR3::Dot(const GEKVECTOR3 &kVector)
{
	return ((x * kVector.x) +
			(y * kVector.y) + 
			(z * kVector.z));
}

inline float GEKVECTOR3::GetLengthSqr(void) const
{
	return Dot(*this);
}

inline float GEKVECTOR3::GetLengthSqr(void)
{
	return Dot(*this);
}

inline float GEKVECTOR3::GetLength(void) const
{
	return SQRT(GetLengthSqr());
}

inline float GEKVECTOR3::GetLength(void)
{
	return SQRT(GetLengthSqr());
}

inline void GEKVECTOR3::SetLength(float fLength)
{
	*this *= (fLength / GetLength());
}

inline float GEKVECTOR3::Distance(const GEKVECTOR3 &kVector) const
{
	return (kVector - *this).GetLength();
}

inline float GEKVECTOR3::Distance(const GEKVECTOR3 &kVector)
{
	return (kVector - *this).GetLength();
}

inline float GEKVECTOR3::GetAngle(const GEKVECTOR3 &kVector)
{
	float fDot = Dot(kVector);
	float fMagnitude = (GetLength() * kVector.GetLength());
	return acosf(fDot / fMagnitude);
}

inline GEKVECTOR3 GEKVECTOR3::Cross(const GEKVECTOR3 &kVector) const
{
	return GEKVECTOR3(((y * kVector.z) - (z * kVector.y)),
					  ((z * kVector.x) - (x * kVector.z)),
					  ((x * kVector.y) - (y * kVector.x)));
}

inline GEKVECTOR3 GEKVECTOR3::Cross(const GEKVECTOR3 &kVector)
{
	return GEKVECTOR3(((y * kVector.z) - (z * kVector.y)),
					  ((z * kVector.x) - (x * kVector.z)),
					  ((x * kVector.y) - (y * kVector.x)));
}

inline GEKVECTOR3 GEKVECTOR3::Lerp(const GEKVECTOR3 &kVector, float fFactor) const
{
	return (*this + ((kVector - *this) * fFactor));
}

inline GEKVECTOR3 GEKVECTOR3::Lerp(const GEKVECTOR3 &kVector, float fFactor)
{
	return (*this + ((kVector - *this) * fFactor));
}

inline GEKVECTOR3 GEKVECTOR3::Normal(void) const
{
	float fLength = GetLength();
	return (*this * (1.0f / fLength));
}

inline GEKVECTOR3 GEKVECTOR3::Normal(void)
{
	float fLength = GetLength();
	return (*this * (1.0f / fLength));
}

inline void GEKVECTOR3::Normalize(void)
{
	*this = Normal();
}