#include "..\GEKXMath.h"

GEKRAY::GEKRAY(void)
{
}

GEKRAY::GEKRAY(const GEKVECTOR3 &kOrigin, const GEKVECTOR3 &kVector)
{
	m_kOrigin = kOrigin;
	m_kVector = kVector;
}

bool GEKAABB::Collision(const GEKAABB &kAABB) const
{
	if(m_kMin > kAABB.m_kMax) return false;
	if(m_kMax < kAABB.m_kMin) return false;
	return true;
}

inline bool GEK_AABB_Sphere_Collision(const GEKSPHERE &kSphere, const GEKAABB &kAABB)
{
	float fDistance = 0.0f;
	for(int iAxis = 0; iAxis < 3; iAxis++)
	{
		if(kSphere.m_kOrigin[iAxis] < kAABB.m_kMin[iAxis])
		{
			float fValue = (kSphere.m_kOrigin[iAxis] - kAABB.m_kMin[iAxis]);
			fDistance += (fValue * fValue);
		}
		else if(kSphere.m_kOrigin[iAxis] > kAABB.m_kMax[iAxis])
		{
			float fValue = (kSphere.m_kOrigin[iAxis] - kAABB.m_kMax[iAxis]);
			fDistance += (fValue * fValue);
		}
	}

	if(fDistance <= (kSphere.m_fRadius * kSphere.m_fRadius)) return true;
	return false;
}

bool GEKAABB::Collision(const GEKSPHERE &kSphere) const
{
	return GEK_AABB_Sphere_Collision(kSphere, *this);
}

void GEKAABB::Extend(const GEKVECTOR3 &kPoint)
{
	if(kPoint.x < m_kMin.x) m_kMin.x = kPoint.x;
	if(kPoint.y < m_kMin.y) m_kMin.y = kPoint.y;
	if(kPoint.z < m_kMin.z) m_kMin.z = kPoint.z;
	if(kPoint.x > m_kMax.x) m_kMax.x = kPoint.x;
	if(kPoint.y > m_kMax.y) m_kMax.y = kPoint.y;
	if(kPoint.z > m_kMax.z) m_kMax.z = kPoint.z;
}

GEKSPHERE::GEKSPHERE(void)
{
	m_fRadius = 0.0f;
}

GEKSPHERE::GEKSPHERE(const GEKVECTOR3 &kOrigin, float fRadius)
{
	m_kOrigin = kOrigin;
	m_fRadius = fRadius;
}

bool GEKSPHERE::Collision(const GEKAABB &kAABB) const
{
	return GEK_AABB_Sphere_Collision(*this, kAABB);
}

bool GEKSPHERE::Collision(const GEKSPHERE &kSphere) const
{
	GEKVECTOR3 kDistance(m_kOrigin - kSphere.m_kOrigin);
	float fDistance = kDistance.GetLengthSqr();

	float fRadius = (m_fRadius + kSphere.m_fRadius);
	if(fDistance <= (fRadius * fRadius)) return true;
	return false;
}